@@ -20,6 +20,7 @@ def getTaskMetadataFromECS():
     log_stream_name = 'ecs/' + container_name + '/' + task_id
 
     return dict(
+        task_id=task_id,
         logGroupName=log_group_name,
         logStreamName=log_stream_name,
         region=os.getenv('AWS_REGION', None),
@@ -34,7 +35,7 @@ def wrapMainFunction(dagger_api, func, task_name=None, task_run_id=None):
     task_metadata = getTaskMetadataFromECS()
 
     if task_run_id is None:
-        task_run_id = task_metadata['ecs_container_metadata']['Labels']['com.amazonaws.ecs.task-arn']
+        task_run_id = task_metadata['task_id']
 
     def _wrapper(*args, **kwargs):
         task = None
